# EmphysemaSeg
Lobe segmentation and emphysema quantification


## Usage with python
1. Populate `config.YAML` with location of directories and model weights
2. Run:
```
EmphysemaSeg--config config.YAML
```
## Usage with Docker

